@@ -75,6 +75,12 @@ namespace giac {
     static rootmap * ans= new rootmap;
     return *ans;
   }
+
+  static rootmap & galoisconj_list(){
+    static rootmap * ans= new rootmap;
+    return *ans;
+  }
+
 #ifdef HAVE_LIBPTHREAD
   static pthread_mutex_t rootof_mutex = PTHREAD_MUTEX_INITIALIZER;
   static int rootof_trylock(){
@@ -84,10 +90,94 @@ namespace giac {
     pthread_mutex_unlock(&rootof_mutex);
   }
 #else
-  static int rootof_trylock(){ return true; }
+  static int rootof_trylock(){ return 0; }
   static void rootof_unlock(){ } 
 
 #endif
+  // get Galois conjugates in the same number field from cache
+  bool galoisconj_cached(const vecteur & v,vecteur & res){
+    if (rootof_trylock())
+      return false;
+    res.clear();
+    rootmap::iterator ritend=galoisconj_list().end(),rit=galoisconj_list().find(v);
+    if (rit!=ritend && rit->second.type==_VECT)
+      res=*rit->second._VECTptr;
+    rootof_unlock();
+    return !res.empty();
+  }
+
+  // cache list of Galois conjugates
+  bool galoisconj_cache(const vecteur & v,const vecteur & res){
+    if (rootof_trylock())
+      return false;
+    rootmap::iterator ritend=galoisconj_list().end(),rit=galoisconj_list().find(v);
+    if (rit==ritend)
+      galoisconj_list()[v]=res;
+    rootof_unlock();
+    return true;
+  }
+
+  vecteur galoisconj(const vecteur & v,GIAC_CONTEXT){
+    vecteur res;
+    if (galoisconj_cached(v,res))
+      return res;
+    gen g=symb_horner(v,vx_var);
+    if (pari_galoisconj(g,res,contextptr))
+      return res;
+    if (int(v.size())>MAX_COMMON_ALG_EXT_ORDER_SIZE) return res;
+    // factor v over rootof(v) if degree is small
+    g=_factors(makesequence(g,rootof(g,contextptr)),contextptr);
+    if (g.type!=_VECT) return res;
+    vecteur w=*g._VECTptr;
+    for (int i=0;i<int(w.size())-1;i+=2){
+      gen a,b;
+      if (is_linear_wrt(w[i],vx_var,a,b,contextptr) && !is_zero(a)){
+	res.push_back(-b/a);
+      }
+    }
+    galoisconj_cache(v,res);
+    return res;
+  }
+
+  gen _galoisconj(const gen & args,GIAC_CONTEXT){
+    gen g=args;
+    if (g.type==_SYMB)
+      g=_symb2poly(args,contextptr);
+    if (g.type!=_VECT) return gensizeerr(contextptr);
+    return galoisconj(*g._VECTptr,contextptr);
+  }
+  static const char _galoisconj_s []="galoisconj";
+  static define_unary_function_eval (__galoisconj,&giac::_galoisconj,_galoisconj_s);
+  define_unary_function_ptr5( at_galoisconj ,alias_at_galoisconj,&__galoisconj,0,true);
+
+  // if true, g is a rootof such that conj(rootof(w))=g
+  bool conj_in_nf(const vecteur & w,gen & g,GIAC_CONTEXT){
+    gen r1=rootof(w,contextptr);
+    vecteur c=galoisconj(w,contextptr);
+    gen pow10=pow(10,14,contextptr);
+    int maxdigits=1000;
+    if (c.size()<w.size()-1)
+      maxdigits=50;
+#ifndef HAVE_LIBMPFR
+    maxdigits=14;
+#endif
+    gen borne=100;
+    for (int ndigits=14;ndigits<=maxdigits;ndigits*=2){
+      gen R1=conj(_evalf(makesequence(r1,ndigits),contextptr),contextptr);
+      for (int i=0;i<int(c.size());++i){
+	gen r2=c[i];
+	gen R2=_evalf(makesequence(r2,ndigits),contextptr);
+	if (is_greater(borne*abs(R1,contextptr),abs(R1-R2,contextptr)*pow10,contextptr)){
+	  g=r2;
+	  return true;
+	}
+      }
+      pow10=pow10*pow10;
+      borne=borne*borne;
+    }
+    return false;
+  }
+
   bool proot_cached(const vecteur & v,double eps,vecteur & res){
     if (rootof_trylock())
       return false;
@@ -177,7 +267,7 @@ namespace giac {
     int n=decimal_digits(contextptr);
     if (n<12) n=12;
     double eps=std::pow(0.1,n);
-    int rprec=n*3.3;
+    int rprec=int(n*3.3);
     vecteur a=proot(v,eps,rprec);
     return in_select_root(a,is_real(v,contextptr),contextptr);
   }
@@ -287,7 +377,7 @@ namespace giac {
   static vecteur replace_ext(const vecteur & v,const vecteur &ext,const gen & g,GIAC_CONTEXT){
     vecteur res;
     const_iterateur it=v.begin(),itend=v.end();
-    res.reserve(itend-it);
+    res.reserve(int(itend-it));
     for (;it!=itend;++it){
       gen numtmp=*it,dentmp=1;
       if (it->type==_FRAC){
@@ -313,7 +403,7 @@ namespace giac {
   gen common_minimal_POLY(const gen & ga,const gen & gb, gen & a,gen & b,int & k,GIAC_CONTEXT){
     const vecteur & va=*ga._VECTptr;
     const vecteur & vb=*gb._VECTptr;
-    int na=va.size()-1,nb=vb.size()-1;
+    int na=int(va.size()-1),nb=int(vb.size()-1);
     if (nb==1){
       k=0;
       vecteur un(2,zero);
@@ -384,7 +474,7 @@ namespace giac {
 	    vecteur rac2=proot(v2,1e-12);
 	    if (!rac2.empty() && !is_undef(rac2)){
 	      gen theta2=in_select_root(rac2,is_real(v2,contextptr),contextptr);
-	      int racs=rac1.size();
+	      int racs=int(rac1.size());
 	      for (int i=0;i<racs;++i){
 		gen r1=rac1[i],K;
 		if (r1==theta1)
@@ -426,7 +516,7 @@ namespace giac {
 	    vecteur rac2=real_proot(v2,1e-12,contextptr);
 	    if (!rac2.empty() && !is_undef(rac2)){
 	      gen theta2=_max(rac2,contextptr);
-	      int racs=rac.size();
+	      int racs=int(rac.size());
 	      for (int i=0;i<racs;++i){
 		gen r1=rac[i],K;
 		if (r1==theta1)
@@ -584,7 +674,7 @@ namespace giac {
 
   // Find an evaluation point for p at b where pb=p[b] is squarefree
   bool find_good_eval(const polynome & F,polynome & Fb,vecteur & b){
-    int Fdeg=F.lexsorted_degree(),nvars=b.size();
+    int Fdeg=F.lexsorted_degree(),nvars=int(b.size());
     gen Fg;
     int essai=0;
     for (;;++essai){
@@ -622,6 +712,31 @@ namespace giac {
     }
   }
 
+  // in-place reduction of algebraic extensions
+  void clean_ext_reduce(vecteur & v){
+    iterateur it=v.begin(),itend=v.end();
+    for (;it!=itend;++it)
+      clean_ext_reduce(*it);
+  }
+  void clean_ext_reduce(gen & g){
+    if (g.type==_EXT){
+      g=ext_reduce(g);
+      return;
+    }
+    if (g.type==_VECT){
+      clean_ext_reduce(*g._VECTptr);
+      return;
+    }
+    if (g.type==_POLY){
+      vector< monomial<gen> >::iterator it=g._POLYptr->coord.begin(),itend=g._POLYptr->coord.end();
+      for (;it!=itend;++it)
+	clean_ext_reduce(it->value);
+      return;
+    }
+    if (g.type==_FRAC)
+      clean_ext_reduce(g._FRACptr->num);
+  }
+
   // a and b are supposed to be *(_EXTptr+1) of some algebraic extension
   // common_EXT will return a new algebraic extension 
   // (suitable to be an extptr+1)
@@ -650,7 +765,7 @@ namespace giac {
 	return gensizeerr(gettext("alg_ext.cc/common_EXT"));
       b__VECT=*(b._EXTptr+1);
     }
-    int as=a__VECT._VECTptr->size(),bs=b__VECT._VECTptr->size();
+    int as=int(a__VECT._VECTptr->size()),bs=int(b__VECT._VECTptr->size());
     if (bs>as)
       return common_EXT(b,a,l,contextptr);
     if (as==3 && bs==3 && is_one(a[0]) && is_one(b[0]) && is_zero(a[1]) && is_zero(b[1]) && a[2]==-b[2]){ // sqrt(X) and sqrt(-X)
@@ -669,7 +784,7 @@ namespace giac {
     // this is done by approximation if possible
     // or by choosing the factor of lowest degree
     // this way we update b__VECT
-    int min_deg=b__VECT._VECTptr->size();
+    int min_deg=int(b__VECT._VECTptr->size());
     factorization::const_iterator f_it=f.begin(),f_itend=f.end();
     bool trouve=false;
     if (f_itend-f_it==1)
@@ -689,8 +804,12 @@ namespace giac {
       if (innerdim){
 	gen params;
 	*logptr(contextptr) << gettext("Warning, need to choose a branch for the root of a polynomial with parameters. This might be wrong.") << endl;
-	if (l->size()>=2){
-	  params=(*l)[1];
+	if (l && l->size()>=2){
+	  for (int i=1;i<l->size();++i){
+	    params=(*l)[i];
+	    if (params.type==_VECT && !params._VECTptr->empty())
+	      break;
+	  }
 	  // IMPROVE: using context and *l look for assumptions
 	  if (params.type==_VECT){
 	    vecteur paramv=*params._VECTptr;
@@ -715,8 +834,12 @@ namespace giac {
 		      else {
 			if (b==plus_inf)
 			  vb[j]=a+1;
-			else
-			  vb[j]=(a+b)/2;
+			else {
+			  if (a+b==0)
+			    vb[j]=b/2;
+			  else
+			    vb[j]=(a+b)/2;
+			}
 		      }
 		    }
 		  }
@@ -731,7 +854,7 @@ namespace giac {
 	if (vb==vb0)
 	  *logptr(contextptr) << gettext("The choice was done assuming ") << params << "=" << vb << endl;       
 	else 
-	  *logptr(contextptr) << gettext("Non regular value ") << vb0 << gettext(" was discarded and replaced randomly by ") << params << "=" << endl;
+	  *logptr(contextptr) << gettext("Non regular value ") << vb0 << gettext(" was discarded and replaced randomly by ") << params << "=" << vb << endl;
 	racines=proot(polynome2poly1(pb));
       }
       else
@@ -1034,7 +1157,7 @@ namespace giac {
       if (it->type==_VECT){
 	const_iterateur jt=it->_VECTptr->begin(),jtend=it->_VECTptr->end();
 	vecteur tmpres;
-	tmpres.reserve(jtend-jt);
+	tmpres.reserve(int(jtend-jt));
 	for (;jt!=jtend;++jt){
 	  if (jt->type==_POLY){
 	    tmp=polynome2poly1(*(jt->_POLYptr),1);
@@ -1137,7 +1260,7 @@ namespace giac {
     if ( g_orig.type!=_VECT || g_orig._VECTptr->size()<3 )
       return gensizeerr(contextptr);
     vecteur v(*g_orig._VECTptr);
-    int s=v.size();
+    int s=int(v.size());
     gen P(v[0]),x(vx_var),a,b;
     if (s==3){ a=v[1]; b=v[2]; } 
     else { 
@@ -1182,7 +1305,7 @@ namespace giac {
     if (g.type!=_VECT || (g.type==_VECT && g.subtype!=_SEQ__VECT) )
       return sturm(g,zero,contextptr);
     vecteur & v = *g._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     if (s==2)
       return sturm(v.front(),v.back(),contextptr);
     if (s==4)
@@ -1369,7 +1492,7 @@ namespace giac {
       // FIXME: check if var is quoted, otherwise it will be erased
       gen savevar=var;
       if (var._IDNTptr->in_eval(1,var,savevar,contextptr))
-	;
+	1;
       giac_assume(symbolic(at_and,makevecteur(symb_superieur_egal(var,range[0]),symb_inferieur_egal(var,range[1]))),contextptr);
       w=solve(df,var,2,contextptr);
       if (savevar==var)
@@ -1380,7 +1503,7 @@ namespace giac {
     if (w.empty() && debug_infolevel)
       *logptr(contextptr) << gettext("Warning: ") << df << gettext("=0: no solution found") << endl;
     vecteur wvar=makevecteur(cst_pi);
-    lidnt(w,wvar);
+    lidnt(w,wvar,false);
     if (wvar.size()>1)
       return undef;
     gen resmin=plus_inf;
@@ -1393,7 +1516,7 @@ namespace giac {
     recompute_minmax(vecteur(1,range[1]),range,expr,var,resmin,resmax,xmin,xmax,-1,contextptr);
     // Singularities
     vecteur ws=find_singularities(expr,*var._IDNTptr,0,contextptr);
-    int wss=ws.size();
+    int wss=int(ws.size());
     w.clear();
     for (int i=0;i<wss;++i){
       if (ws[i]!=range[0] && ws[i]!=range[1])
@@ -1440,7 +1563,7 @@ namespace giac {
 	  return 0;
 	vecteur lv0(lvar(g._SYMBptr->feuille)),lv; // remove cst idnt
 	for (unsigned i=0;i<lv0.size();++i){
-	  if (evalf_double(lv0[i],1,contextptr)!=_DOUBLE_) // if (!is_constant_idnt(lv0[i]))
+	  if (evalf_double(lv0[i],1,contextptr).type!=_DOUBLE_) // if (!is_constant_idnt(lv0[i]))
 	    lv.push_back(lv0[i]);
 	}
 	if (!lv.empty()){
@@ -1493,7 +1616,7 @@ namespace giac {
     // search for a sqrt inside v: sign(a+b*sqrt(c))=
     // = sign(a) if a^2-c*b^2 > 0, 
     // = sign(b) if a^2-c*b^2 < 0
-    int s=v.size();
+    int s=int(v.size());
     if (!s)
       return fastsign(g,contextptr);
     gen v0(v[0]);
@@ -1606,7 +1729,7 @@ namespace giac {
     if (g.is_symb_of_sommet(at_prod)){
       gen &f=g._SYMBptr->feuille;
       vecteur v(gen2vecteur(f));
-      int s=v.size();
+      int s=int(v.size());
       vecteur w;
       int res=1,currentsign;
       // remove cst coeffs and exp/
