@@ -593,7 +593,7 @@ namespace giac {
   }
 
   static gen prod_expand(const const_iterateur it,const const_iterateur itend,GIAC_CONTEXT){
-    int s=itend-it;
+    int s=int(itend-it);
     if (s==0)
       return plus_one;
     if (s==1)
@@ -609,7 +609,7 @@ namespace giac {
   }
 
   static gen prod_expand_nosimp(const const_iterateur it,const const_iterateur itend,GIAC_CONTEXT){
-    int s=itend-it;
+    int s=int(itend-it);
     if (s==0)
       return plus_one;
     if (s==1)
@@ -679,7 +679,7 @@ namespace giac {
       }
       // (x1+...+xn)^k -> sum_{j1+...+jn=k} k!/(j1!j2!...jn!) x^j1 *... *x^jk
       vecteur & w=*v[0]._SYMBptr->feuille._VECTptr;
-      int n=w.size();
+      int n=int(w.size());
       if (!n)
 	return gensizeerr(contextptr);
       vecteur res;
@@ -742,8 +742,12 @@ namespace giac {
       return -ln_expand0(e._SYMBptr->feuille,contextptr);
     if (e._SYMBptr->sommet==at_pow){
       gen & tmp=e._SYMBptr->feuille;
-      if (tmp.type==_VECT && tmp._VECTptr->size()==2)
-	return tmp._VECTptr->back()*ln_expand0(tmp._VECTptr->front(),contextptr);
+      if (tmp.type==_VECT && tmp._VECTptr->size()==2){
+	gen base=tmp._VECTptr->front(),expo=tmp._VECTptr->back();
+	if (!complex_mode(contextptr) && expo.type==_INT_ && expo.val%2==0)
+	  base=abs(base,contextptr);
+	return expo*ln_expand0(base,contextptr);
+      }
     }
     return ln(e,contextptr);
   }
@@ -760,7 +764,7 @@ namespace giac {
       return v.back();
     gen res=zero;
     const_iterateur it=v.begin(),itend=v.end();
-    int n=itend-it-1;
+    int n=int(itend-it)-1;
     for (;it!=itend;++it,--n)
       res = res + (*it)*pow(e,n);
     return res;
