@@ -157,7 +157,8 @@ namespace giac {
       res=res*pow2sizeof_long+longlong(unsigned(G[i]));
 #endif
     }
-    res=res*evalf(pow(plus_two,int(expo(G)+1-bit_accuracy(n))),1,0);
+    res=res*pow(plus_two,int(expo(G)+1-bit_accuracy(n)));
+    res=_evalf(makesequence(res,int(n/3.3)),context0);
     return Gs<0?-res:res;
   }
 
@@ -427,6 +428,7 @@ namespace giac {
       res=gmul(res,Gstep);
       res=gadd(res,utoi(v[i]));
     }
+    setsigne(res,sgn);
     return res;
   }
 
@@ -488,15 +490,19 @@ namespace giac {
       e=-e;
       neg=true;
     }
-    const char * s=e.print(contextptr).c_str();
     int prec=53;
 #ifdef HAVE_LIBMPFR
     if (e.type==_REAL)
       prec=mpfr_get_prec(e._REALptr->inf);
 #endif
+    const char * s=e.print(contextptr).c_str();
     GEN g=strtor((char *)s,prec);
     if (neg)
       g=gneg(g);
+    if (debug_infolevel)
+      CERR << "real converted to pari " << GEN2gen(g,vecteur(0)) << endl;
+    else e=GEN2gen(g,vecteur(0));
+    // for some strange reason, converting g to a gen fixes a bug in conversion
     return g;
   }
 
@@ -543,16 +549,22 @@ namespace giac {
   }
 
   static void pari_cleanup(void * arg) {
+#ifdef HAVE_LIBPTHREAD
     if (arg)
       pthread_mutex_unlock((pthread_mutex_t *)arg);
+#endif
   }
 
   int check_pari_mutex(){
+#ifdef HAVE_LIBPTHREAD
     if (!pari_mutex_ptr){
       pthread_mutex_t tmp=PTHREAD_MUTEX_INITIALIZER;
       pari_mutex_ptr=new pthread_mutex_t(tmp);
     }
     return pthread_mutex_trylock(pari_mutex_ptr);
+#else
+    return 0;
+#endif
   }
 
   void abort_if_locked(){
@@ -563,80 +575,104 @@ namespace giac {
   gen pari_isprime(const gen & e,int certif){
     gen tmp;
     abort_if_locked();
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     tmp=GEN2gen(gisprime(gen2GEN(e,vecteur(0),0),certif),vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return tmp;
   }
 
   string pari_ifactor(const gen & e){
     abort_if_locked();
     string s;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     GEN g=gen2GEN(e,vecteur(0),0);
     GEN gf=factorint(g,0);
     s=GEN2string(gf);
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return s;
   }
 
   gen pari_gamma(const gen & e){
     abort_if_locked();
     gen res;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     GEN g=gen2GEN(e,vecteur(0),0);
     GEN gf=ggamma(g,precision(g));
     res=GEN2gen(gf,vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return res;
   }
 
   gen pari_zeta(const gen & e){
     abort_if_locked();
     gen res;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     GEN g=gen2GEN(e,vecteur(0),0);
     GEN gf=gzeta(g,precision(g));
     res=GEN2gen(gf,vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return res;
   }
 
   gen pari_psi(const gen & e){
     abort_if_locked();
     gen res;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     GEN g=gen2GEN(e,vecteur(0),0);
     GEN gf=gpsi(g,precision(g));
     res=GEN2gen(gf,vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return res;
   }
 
   gen pari_ffinit(const gen & p,int n){
     gen tmp;
+#ifdef HAVE_LIBPTHREAD
     abort_if_locked();
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     tmp=GEN2gen(ffinit(gen2GEN(p,vecteur(0),0),n,0),vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return tmp;
   }
 
@@ -690,7 +726,9 @@ namespace giac {
     if (setjmp(env))
 #endif
       { 
+#ifdef HAVE_LIBPTHREAD
 	if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
+#endif
 	avma = av;
 	*logptr(contextptr) << gettext("Error in PARI subsystem") << endl;
 	PARI_stack_limit = save_pari_stack_limit ;
@@ -748,7 +786,7 @@ namespace giac {
     for (int i=1;i<vs;i++)
       v[i]=v[i].eval(eval_level(contextptr),contextptr);
     vecteur vars(1,identificateur("O"));
-    lidnt(v,vars);
+    lidnt(v,vars,false);
     vars.erase(vars.begin());
     bool parse_all=false;
     long av=avma;
@@ -757,7 +795,9 @@ namespace giac {
       avma = av;
       parse_all=true;
       if (setjmp(GP_DATA->env)){ // if (setjmp(GP_DATA->env)){
+#ifdef HAVE_LIBPTHREAD
 	if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
+#endif
 	avma = av;
 	*logptr(contextptr) << gettext("Error in PARI subsystem") << endl;
 	// setsizeerr();
@@ -770,7 +810,9 @@ namespace giac {
       avma = av;
       parse_all=true;
       if (setjmp(env)){ // if (setjmp(GP_DATA->env)){
+#ifdef HAVE_LIBPTHREAD
 	if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
+#endif
 	avma = av;
 	*logptr(contextptr) << gettext("Error in PARI subsystem") << endl;
 	// setsizeerr();
@@ -917,10 +959,14 @@ namespace giac {
     if ( args.type==_STRNG && args.subtype==-1) return  args;
     abort_if_locked();
     gen res;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     res=in_pari(args,contextptr);
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     return res;
   }
   static const char _pari_s []="pari";
@@ -932,8 +978,10 @@ namespace giac {
     int locked=check_pari_mutex();
     if (!locked)
       return 0;
+#ifdef HAVE_LIBPTHREAD
     delete pari_mutex_ptr;
     pari_mutex_ptr = 0;
+#endif
     return 1;
   }
   static const char _pari_unlock_s []="pari_unlock";
@@ -992,14 +1040,20 @@ namespace giac {
     if (check_pari_mutex())
       return false;
     gen tmp;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     GEN G=gen2GEN(change_subtype(p,_POLY1__VECT),vecteur(0),contextptr);
+    if (debug_infolevel)
+      CERR << "pari_polroots " << GEN2gen(G,vecteur(1,vx_var)) << endl;
     G=roots(G,prec);
     tmp=GEN2gen(G,vecteur(0));
     avma=av;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     if (tmp.type!=_VECT)
       return false;
     res=*tmp._VECTptr;
@@ -1010,7 +1064,9 @@ namespace giac {
     if (check_pari_mutex())
       return false;
     gen tmp;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     void * save_pari_stack_limit = PARI_stack_limit;
     PARI_stack_limit=0; 
@@ -1020,8 +1076,10 @@ namespace giac {
     tmp=GEN2gen(PQ,lv);
     avma=av;
     PARI_stack_limit=save_pari_stack_limit;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     res=tmp;
     return true;
   }
@@ -1030,7 +1088,9 @@ namespace giac {
     if (check_pari_mutex())
       return false;
     gen tmp;
+#ifdef HAVE_LIBPTHREAD
     pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
     long av=avma;
     void * save_pari_stack_limit = PARI_stack_limit;
     PARI_stack_limit=0; 
@@ -1043,12 +1103,41 @@ namespace giac {
     tmp=GEN2gen(nffactor(nf,P),lv);
     avma=av;
     PARI_stack_limit=save_pari_stack_limit;
+#ifdef HAVE_LIBPTHREAD
     if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
     pthread_cleanup_pop(0);
+#endif
     res=tmp;
     return true;
   }
 
+  bool pari_galoisconj(const gen & g,vecteur & w,GIAC_CONTEXT){
+    if (check_pari_mutex())
+      return false;
+    gen res;
+#ifdef HAVE_LIBPTHREAD
+    pthread_cleanup_push(pari_cleanup, (void *) pari_mutex_ptr);
+#endif
+    res=in_pari(makesequence(string2gen("nfgaloisconj",false),g),contextptr);
+#ifdef HAVE_LIBPTHREAD
+    if (pari_mutex_ptr) pthread_mutex_unlock(pari_mutex_ptr);    
+    pthread_cleanup_pop(0);
+#endif
+    if (res.type!=_VECT)
+      return false;
+    w=*res._VECTptr;
+    gen gp=_symb2poly(makesequence(g,vx_var),contextptr);
+    for (int i=0;i<int(w.size());++i){
+      gen tmp=w[i];
+      tmp=_symb2poly(makesequence(tmp,vx_var),contextptr);
+      gen d=1;
+      if (tmp.type==_VECT)
+	lcmdeno(*tmp._VECTptr,d,contextptr);
+      w[i]=symb_rootof(tmp,gp,contextptr)/d;
+    }
+    return true;
+  }
+  
 
 #ifndef NO_NAMESPACE_GIAC
 }
@@ -1092,6 +1181,10 @@ namespace giac {
     return false;
   }
 
+  bool pari_galoisconj(const gen & g,vecteur & w,GIAC_CONTEXT){
+    return false;
+  }
+  
   gen _pari(const gen & args,GIAC_CONTEXT){
     if ( args.type==_STRNG && args.subtype==-1) return  args;
     return pari_error();
